@@ -1,6 +1,6 @@
 structure(list(method = "GET", url = "/list?logical-path=%2Fprojectx&stat=0&permissions=0&metadata=0&offset=0&limit=100", 
     status_code = 400L, headers = structure(list(Server = "nginx/1.23.1", 
-        Date = "Thu, 29 Jun 2023 06:41:10 GMT", `Content-Length` = "84", 
+        Date = "Sun, 29 Oct 2023 09:45:54 GMT", `Content-Length` = "84", 
         Connection = "keep-alive", `Access-Control-Allow-Origin` = "*", 
         `Access-Control-Allow-Headers` = "*", `Access-Control-Allow-Methods` = "AUTHORIZATION,ACCEPT,GET,POST,OPTIONS,PUT,DELETE"), class = "httr2_headers"), 
     body = raw(0)), class = "httr2_response")
