@@ -1,6 +1,6 @@
 structure(list(method = "PUT", url = "/stream?logical-path=%2FtempZone%2Fhome%2Frods%2Ftestthat%2Fdfr.csv&offset=0&count=2000&truncate=true", 
     status_code = 200L, headers = structure(list(Server = "nginx/1.23.1", 
-        Date = "Thu, 29 Jun 2023 06:40:54 GMT", `Content-Length` = "33", 
+        Date = "Sun, 29 Oct 2023 09:45:33 GMT", `Content-Length` = "33", 
         Connection = "keep-alive", `Access-Control-Allow-Origin` = "*", 
         `Access-Control-Allow-Headers` = "*", `Access-Control-Allow-Methods` = "AUTHORIZATION,ACCEPT,GET,POST,OPTIONS,PUT,DELETE"), class = "httr2_headers"), 
     body = as.raw(c(0x7b, 0x22, 0x63, 0x6f, 0x64, 0x65, 0x22, 
